---
title: <span class="badge object-type-scalar"></span> MicroBitcoin
---
# <span class="badge object-type-scalar"></span> MicroBitcoin

Currency: Micro Bitcoin (฿)

## Definition

```python
# Currency: Micro Bitcoin (฿)
MicroBitcoin: typing.Literal["currencyμBTC"] = "currencyμBTC"
```
